summaryrefslogtreecommitdiff
path: root/source/components/resources
diff options
context:
space:
mode:
authorRobert Moore <Robert.Moore@intel.com>2011-09-13 09:09:21 -0700
committerLin Ming <ming.m.lin@intel.com>2011-11-10 10:10:25 +0800
commitf5bac5a6db2589b5cf3cf3d97ac4bd424cc81a50 (patch)
treee190cbcb2d6ae15471400ed42d59cc59a75fbfcf /source/components/resources
parenta59ec65befde81678e179899a0c54bc590e61533 (diff)
ACPI 5.0/ResourceMgr: Allow _AEI method in walk resources.
_AEI contains a resource template, this change adds support for the walk resources function. Zhang Rui.
Diffstat (limited to 'source/components/resources')
-rw-r--r--source/components/resources/rsxface.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/source/components/resources/rsxface.c b/source/components/resources/rsxface.c
index 6646ef18e..129252d81 100644
--- a/source/components/resources/rsxface.c
+++ b/source/components/resources/rsxface.c
@@ -616,8 +616,9 @@ AcpiRsMatchVendorResource (
*
* PARAMETERS: DeviceHandle - Handle to the device object for the
* device we are querying
* Name - Method name of the resources we want
* (METHOD_NAME__CRS or METHOD_NAME__PRS)
* UserFunction - Called for each resource
* Context - Passed to UserFunction
*
@@ -649,12 +650,13 @@ AcpiWalkResources (
if (!DeviceHandle || !UserFunction || !Name ||
(!ACPI_COMPARE_NAME (Name, METHOD_NAME__CRS) &&
- !ACPI_COMPARE_NAME (Name, METHOD_NAME__PRS)))
+ !ACPI_COMPARE_NAME (Name, METHOD_NAME__PRS) &&
+ !ACPI_COMPARE_NAME (Name, METHOD_NAME__AEI)))
{
return_ACPI_STATUS (AE_BAD_PARAMETER);
}
/* Get the _CRS or _PRS resource list */
Buffer.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
Status = AcpiRsGetMethodData (DeviceHandle, Name, &Buffer);
@@ -616,8 +616,9 @@ AcpiRsMatchVendorResource (
* PARAMETERS: DeviceHandle - Handle to the device object for the
* device we are querying
- * Name - Method name of the resources we want
- * (METHOD_NAME__CRS or METHOD_NAME__PRS)
+ * Name - Method name of the resources we want.
+ * (METHOD_NAME__CRS, METHOD_NAME__PRS, or
+ * METHOD_NAME__AEI)
* UserFunction - Called for each resource
* Context - Passed to UserFunction
@@ -649,12 +650,13 @@ AcpiWalkResources (
return_ACPI_STATUS (AE_BAD_PARAMETER);
}
- /* Get the _CRS or _PRS resource list */
+ /* Get the _CRS/_PRS/_AEI resource list */
Buffer.Length = ACPI_ALLOCATE_LOCAL_BUFFER;
Status = AcpiRsGetMethodData (DeviceHandle, Name, &Buffer);